@@ -11,7 +11,10 @@ import os.path
 
 logger = logging.getLogger()
 import codecs
-import yaml
+# import ruamel.yaml as yaml
+from ruamel.yaml import YAML
+yaml = YAML(typ='unsafe')
+
 
 import platform
 
@@ -656,12 +659,12 @@ class SimpleEditor(Toplevel):
         logger.debug('target: {0}'.format(target))
         if target:
             where = self.text.search(target, INSERT, nocase=1)
-        if where:
-            pastit = where + ('+%dc' % len(target))
-            self.text.tag_add(FOUND, where, pastit)
-            self.text.mark_set(INSERT, pastit)
-            self.text.see(INSERT)
-            self.text.focus()
+            if where:
+                pastit = where + ('+%dc' % len(target))
+                self.text.tag_add(FOUND, where, pastit)
+                self.text.mark_set(INSERT, pastit)
+                self.text.see(INSERT)
+                self.text.focus()
 
     def cancel(self, e=None):
         t = self.find_text.get()
@@ -1163,7 +1166,7 @@ class Timer():
             self.currentStatus,
             self.currentMinutes,
             self.idlestart,
-            self.idletime
+            self.idletime,
         )
         fo = codecs.open(self.etmtimers, 'w', self.dfile_encoding)
         yaml.dump(tmp, fo)
